/*
 * Some kind of text console for the GP32
 * Copyright (C) 2004 Thomas Mathys
 * http://members.vantage.ch/killer
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef _CONSOLE_H
#define _CONSOLE_H

#ifdef __cplusplus
extern "C" {
#endif

#include <gpdef.h>

// max. # of chars conPrintf can display + 1
// value affects stack usage of conPrintf
#define CON_PRINTF_MAXCHARS	256

#define CON_CHARWIDTH		8
#define CON_CHARHEIGHT		8
#define CON_WIDTH		(GPC_LCD_WIDTH / CON_CHARWIDTH)
#define CON_HEIGHT		(GPC_LCD_HEIGHT / CON_CHARHEIGHT)

#define CON_NCOLORS		16
#define CON_BLACK		0
#define CON_BLUE		1
#define CON_GREEN		2
#define CON_CYAN		3
#define CON_RED			4
#define CON_MAGENTA		5
#define CON_BROWN		6
#define CON_LIGHTGREY		7
#define CON_GREY		8
#define CON_LIGHTBLUE		9
#define CON_LIGHTGREEN		10
#define CON_LIGHTCYAN		11
#define CON_LIGHTRED		12
#define CON_LIGHTMAGENTA	13
#define CON_YELLOW		14
#define CON_WHITE		15


// init console
void conInit(void);


// set/get cursor position
// if invalid coordinates (>= CON_WIDTH/CON_HEIGHT)
// are passed, the set functions do nothing.
void conSetXY(u32 x, u32 y);
void conSetX(u32 x);
void conSetY(u32 y);
u32 conGetX(void);
u32 conGetY(void);


// set/get foreground/background color.
// if invalid color indices (>= CON_NCOLORS)
// are passed, the set functions do nothing.
void conSetFgColor(u32 color);
void conSetBgColor(u32 color);
u32 conGetFgColor(void);
u32 conGetBgColor(void);


// set/get tabulator size.
// if an invalid value (>= CON_WIDTH) is passed
// to conSetTabSize, the tab size won't be changed.
void conSetTabSize(u32 size);
u32 conGetTabSize(void);


// basic character drawing
// these functions draw a character at x/y without modifying
// the cursor. if invalid values are passed
// (invalid coordinates or colors), the functions do nothing.
//
// x	:	x coordinate
// y	:	y coordinate
// c	:	character to draw
// fg	:	foreground color
// bg	:	background color
void conDrawChar(u32 x, u32 y, char c);
void conDrawCharAttr(u32 x, u32 y, char c, u32 fg, u32 bg);


// clear screen functions
// all functions set the cursor to x=0, y=0
// if invalid values are passed, the functions do nothing.
//
// c	:	character to fill screen with
// fg	:	foreground color
// bg	:	background color
void conClr(void);	// uses space and current fg/bg colors
void conClrCharAttr(char c, u32 fg, u32 bg);


// print single character.
// the cursor is advanced to the next position.
// if the cursor was in the lower right corner
// of the screen, the screen is scrolled up one line.
// conPutchRaw() will output any character, while
// conPutch() handles the \a,\b,\f,\n,\r,\t,\v
// characters.
//
// c	:	character to print
//
void conPutchRaw(char c);
void conPutch(char c);


// print zero terminated string
void conPrintRaw(const char *s);
void conPrint(const char *s);

// works like printf, uses conPrint (not conPrintRaw)
void conPrintf(const char *string, ...);

// enable/disable beeping when conPutch/conPrint/conPrintf
// encounter a \a character.
//
// enable	:	zero disables beeping
//			nonzero enables beeping
void conEnableBeep(u8 enable);

// returns wether beeping is enabled
// return value	:	zero = beeping is disabled
//			nonzero = beeping is enabled
u32 conIsBeepEnabled(void);


#ifdef __cplusplus
}
#endif

#endif
