# Makefile for GP32 development using devkitadv under Win32
# Written 2002 by Christian Nowak <chnowak@web.de>

# Settings
PREFIX=arm-agb-elf-

CC=$(CCBASE)/bin/$(PREFIX)gcc
CFLAGS=$(CUSER) \
		-mcpu=arm9tdmi \
		-mtune=arm9tdmi \
		-fexpensive-optimizations \
		-mapcs \
		-O3 \
		-mstructure-size-boundary=8 \
		-mno-thumb-interwork \
		-fno-builtin \
		-fno-common \
		-fno-exceptions \
		-finline-functions \
		-fomit-frame-pointer \
		-fshort-enums \
		-ffast-math \
		-fshort-double \
		-fallow-single-precision \
		-ffreestanding \
		-I$(CCBASE)/arm-agb-elf/include/gp32 \
		-I$(CCBASE)/arm-agb-elf/include

CPPFLAGS=$(CUSER) \
		-mcpu=arm9tdmi \
		-mtune=arm9tdmi \
		-O3 \
		-mstructure-size-boundary=32 \
		-finline-functions \
		-fomit-frame-pointer \
		-mno-thumb-interwork \
		-fno-exceptions \
		-fno-common \
		-fno-builtin \
		-fshort-enums \
		-ffast-math \
		-fshort-double \
		-fexpensive-optimizations \
		-mapcs \
		-I$(CCBASE)/arm-agb-elf/include/gp32 \
		-I$(CCBASE)/arm-agb-elf/include

LD=$(CC)
LNKSCRIPT=$(CCBASE)/arm-agb-elf/lib/lnkscript
LDFLAGS=-Wl,-T $(LNKSCRIPT)
GPLIBS=-lgpsdk -lgpgraphic -lgpmem -lgpos -lgpstdlib -lgpstdio -lgpsound -lgpfont -lgpg_ex01

AS=$(CCBASE)/bin/$(PREFIX)as

# OBJS
GPSTART=$(CCBASE)/arm-agb-elf/lib/gpsdk/gpstart/gpstart.o
GPOBJS=$(GPSTART)
# $(CCBASE)/arm-agb-elf/lib/gp32_fileio/gp32_fileio.o

LINK=$(LD) $(LDFLAGS) -o $@ $^ $(GPOBJS) $(GPLIBS)

OBJCOPY=$(CCBASE)/bin/$(PREFIX)objcopy

# Implicit Rules
%.o: %.c
	$(CC) $(CFLAGS) -c $<

%.o: %.cpp
	$(CC) $(CPPFLAGS) -c $<

%.gxb: %.elf
	$(OBJCOPY) -O binary $< $@

%.o: %.s
	$(AS) -o $@ $<

